==> mriqc-23.0.0.tar.gz: mriqc-23.0.0/.maint/MAINTAINERS.md <==
# Maintainers

This document lists the Maintainers of the project.
Maintainers may be added once approved by the existing maintainers as described in the `../GOVERNANCE.md` document.
By adding your name to this list you are agreeing to abide by the governance documents and to abide by all of the Organization's polices, including the code of conduct, trademark policy, and antitrust policy.
If you are participating because of your affiliation with another organization (designated below), you represent that you have the authority to bind that organization to these policies.

<!-- EXAMPLE: The current contents of the table are given for an example, please update. -->

| **Lastname** | **Name** | **Handle** | **ORCID** | **Affiliation** |
| --- | --- | --- | --- | --- |
| Provins | Céline | @celprov | 0000-0002-1668-9629 | Lausanne University Hospital and University of Lausanne, Lausanne, Switzerland |
| Hagen | McKenzie P. | @mckenziephagen | 0000-0002-7454-8189 | Psychology Department, University of Washington, Seattle, WA, USA |
| MacNicol | Eilidh | @eilidhmacnicol | 0000-0003-3715-7012 | Department of Neuroimaging, Institute of Psychiatry, Psychology and Neuroscience, King's College London, London, UK |
| Esteban | Oscar | @oesteban | 0000-0001-8435-6191 | Lausanne University Hospital and University of Lausanne, Lausanne, Switzerland |
| Baratz | Zvi | @ZviBaratz | 0000-0001-7159-1387 | Sagol School of Neuroscience, Tel Aviv University, Tel Aviv, Israel |
| Markiewicz | Christopher J. | @effigies | 0000-0002-6533-164X | Department of Psychology, Stanford University, CA, USA |

==> mriqc-24.0.0rc6.tar.gz: mriqc-24.0.0rc6/.maint/MAINTAINERS.md <==
# Maintainers

This document lists the Maintainers of the project.
Maintainers may be added once approved by the existing maintainers as described in the `../GOVERNANCE.md` document.
By adding your name to this list you are agreeing to abide by the governance documents and to abide by all of the Organization's polices, including the code of conduct, trademark policy, and antitrust policy.
If you are participating because of your affiliation with another organization (designated below), you represent that you have the authority to bind that organization to these policies.

<!-- EXAMPLE: The current contents of the table are given for an example, please update. -->

| **Lastname** | **Name** | **Handle** | **ORCID** | **Affiliation** |
| --- | --- | --- | --- | --- |
| Provins | Céline | @celprov | 0000-0002-1668-9629 | Department of Radiology, Lausanne University Hospital and University of Lausanne, Switzerland |
| Hagen | McKenzie P. | @mckenziephagen | 0000-0002-7454-8189 | Psychology Department, University of Washington, Seattle, WA, USA |
| MacNicol | Eilidh | @eilidhmacnicol | 0000-0003-3715-7012 | Department of Neuroimaging, Institute of Psychiatry, Psychology and Neuroscience, King's College London, London, UK |
| Esteban | Oscar | @oesteban | 0000-0001-8435-6191 | Lausanne University Hospital and University of Lausanne, Lausanne, Switzerland |
| Baratz | Zvi | @ZviBaratz | 0000-0001-7159-1387 | Sagol School of Neuroscience, Tel Aviv University, Tel Aviv, Israel |
| Markiewicz | Christopher J. | @effigies | 0000-0002-6533-164X | Department of Psychology, Stanford University, CA, USA |
